@@ -12,10 +12,15 @@ import (
 	"net/http"
 	"net/url"
 	"os"
+	"reflect"
+	"strconv"
 	"strings"
 
+	"github.com/tidwall/gjson"
+
 	"github.com/stripe/stripe-cli/pkg/ansi"
 	"github.com/stripe/stripe-cli/pkg/config"
+	"github.com/stripe/stripe-cli/pkg/parsers"
 	"github.com/stripe/stripe-cli/pkg/stripe"
 
 	"github.com/spf13/cobra"
@@ -101,6 +106,8 @@ type Base struct {
 
 	Livemode bool
 
+	IsPreviewCommand bool
+
 	autoConfirm bool
 	showHeaders bool
 }
@@ -109,6 +116,10 @@ var confirmationCommands = map[string]bool{http.MethodDelete: true}
 
 // RunRequestsCmd is the interface exposed for the CLI to run network requests through
 func (rb *Base) RunRequestsCmd(cmd *cobra.Command, args []string) error {
+	if err := stripe.ValidateAPIBaseURL(rb.APIBaseURL); err != nil {
+		return err
+	}
+
 	if len(args) > 1 {
 		return fmt.Errorf("this command only supports one argument. Run with the --help flag to see usage and examples")
 	}
@@ -135,7 +146,7 @@ func (rb *Base) RunRequestsCmd(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
-	_, err = rb.MakeRequest(cmd.Context(), apiKey, path, &rb.Parameters, false, nil)
+	_, err = rb.MakeRequest(cmd.Context(), apiKey, path, &rb.Parameters, make(map[string]interface{}), false, nil)
 
 	return err
 }
@@ -203,24 +214,8 @@ func (rb *Base) MakeMultiPartRequest(ctx context.Context, apiKey, path string, p
 	return rb.performRequest(ctx, client, path, params, reqBody.String(), errOnStatus, configure)
 }
 
-// MakeV2Request will make a application/json request to the Stripe API with the specific payload given to it.
-func (rb *Base) MakeV2Request(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error, jsonPayload string) ([]byte, error) {
-	parsedBaseURL, err := url.Parse(rb.APIBaseURL)
-	if err != nil {
-		return []byte{}, err
-	}
-
-	client := &stripe.Client{
-		BaseURL: parsedBaseURL,
-		APIKey:  apiKey,
-		Verbose: rb.showHeaders,
-	}
-
-	return rb.performRequest(ctx, client, path, params, jsonPayload, errOnStatus, additionalConfigure)
-}
-
 // MakeRequest will make a request to the Stripe API with the specific variables given to it
-func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
+func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *RequestParameters, additionalParams map[string]interface{}, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
 	parsedBaseURL, err := url.Parse(rb.APIBaseURL)
 	if err != nil {
 		return []byte{}, err
@@ -232,13 +227,28 @@ func (rb *Base) MakeRequest(ctx context.Context, apiKey, path string, params *Re
 		Verbose: rb.showHeaders,
 	}
 
-	return rb.MakeRequestWithClient(ctx, client, path, params, errOnStatus, additionalConfigure)
+	return rb.MakeRequestWithClient(ctx, client, path, params, additionalParams, errOnStatus, additionalConfigure)
 }
 
 // MakeRequestWithClient will make a request to the Stripe API with the specific
 // variables given to it using the provided client.
-func (rb *Base) MakeRequestWithClient(ctx context.Context, client stripe.RequestPerformer, path string, params *RequestParameters, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
-	data, err := rb.BuildDataForRequest(params)
+func (rb *Base) MakeRequestWithClient(ctx context.Context, client stripe.RequestPerformer, path string, params *RequestParameters, additionalParams map[string]interface{}, errOnStatus bool, additionalConfigure func(req *http.Request) error) ([]byte, error) {
+	parsedBaseURL, err := url.Parse(rb.APIBaseURL)
+	if err != nil {
+		return []byte{}, err
+	}
+
+	apiGeneration := stripe.V1Request
+	if stripe.IsV2Path(path) {
+		apiGeneration = stripe.V2Request
+	}
+
+	var data string
+	if apiGeneration == stripe.V2Request {
+		data, err = BuildDataForV2Request(rb.Method, path, params.data, additionalParams)
+	} else {
+		data, err = BuildDataForV1Request(rb.Method, parsedBaseURL.Path, params, additionalParams, make(map[string]gjson.Result))
+	}
 	if err != nil {
 		return []byte{}, err
 	}
@@ -250,7 +260,7 @@ func (rb *Base) performRequest(ctx context.Context, client stripe.RequestPerform
 	configure := func(req *http.Request) error {
 		rb.setIdempotencyHeader(req, params)
 		rb.setStripeAccountHeader(req, params)
-		rb.setVersionHeader(req, params)
+		rb.setVersionHeader(req, params, path)
 		if additionalConfigure != nil {
 			if err := additionalConfigure(req); err != nil {
 				return err
@@ -290,7 +300,7 @@ func (rb *Base) performRequest(ctx context.Context, client stripe.RequestPerform
 		}
 
 		result := ansi.ColorizeJSON(string(body), rb.DarkStyle, os.Stdout)
-		fmt.Print(result)
+		fmt.Println(result)
 	}
 
 	return body, nil
@@ -308,8 +318,10 @@ func compileRequestError(body []byte, statusCode int) RequestError {
 
 	var errorBody requestErrorBody
 	json.Unmarshal(body, &errorBody)
+
+	msg := "Request failed"
 	return RequestError{
-		msg:        "Request failed",
+		msg:        msg,
 		StatusCode: statusCode,
 		ErrorType:  errorBody.Content.Type,
 		ErrorCode:  errorBody.Content.Code,
@@ -322,6 +334,64 @@ func (rb *Base) Confirm() (bool, error) {
 	return rb.confirmCommand()
 }
 
+// BuildV1RequestData transforms the v2 post data into v1 post request param shape
+func BuildDataForV1Request(method, apiBaseURL string, requestParams *RequestParameters, additionalParams map[string]interface{}, queryRespMap map[string]gjson.Result) (string, error) {
+	req := Base{
+		Method:         strings.ToUpper(method),
+		SuppressOutput: true,
+		APIBaseURL:     apiBaseURL,
+	}
+
+	v1Params, err := createV1Params(requestParams, additionalParams, queryRespMap)
+	if err != nil {
+		return "", err
+	}
+
+	dataStr, err := req.BuildDataForRequest(v1Params)
+	if err != nil {
+		return "", err
+	}
+
+	return dataStr, nil
+}
+
+// createV1Params combine the data flag and property flag parameters into request parameters
+func createV1Params(requestParams *RequestParameters, additionalParams map[string]interface{}, queryRespMap map[string]gjson.Result) (*RequestParameters, error) {
+	// clean up data param arrays
+	dataFlagParams := make([]string, 0)
+	for _, datum := range requestParams.data {
+		split := strings.SplitN(datum, "=", 2)
+		if len(split) < 2 {
+			return nil, fmt.Errorf("Invalid data argument: %s", datum)
+		}
+
+		if _, ok := additionalParams[split[0]]; ok {
+			return nil, fmt.Errorf("Flag \"%s\" already set", split[0])
+		}
+
+		dataFlagParams = append(dataFlagParams, datum)
+	}
+
+	// merge params
+	result := RequestParameters{}
+	result.AppendData(dataFlagParams)
+	result.AppendExpand(requestParams.expand)
+	result.startingAfter = requestParams.startingAfter
+	result.endingBefore = requestParams.endingBefore
+	result.SetIdempotency(requestParams.idempotency)
+	result.limit = requestParams.limit
+	result.SetStripeAccount("")
+	result.SetVersion("")
+
+	parsed, err := parsers.ParseToFormData(additionalParams, queryRespMap)
+	if err != nil {
+		return &result, err
+	}
+	result.AppendData(parsed)
+
+	return &result, nil
+}
+
 // BuildDataForRequest builds request payload
 // Note: We converted to using two arrays to track keys and values, with our own
 // implementation of Go's url.Values Encode function due to our query parameters being
@@ -371,10 +441,101 @@ func (rb *Base) BuildDataForRequest(params *RequestParameters) (string, error) {
 	return encode(keys, values), nil
 }
 
+// BuildDataForV2Request encodes the parameters for the API request.
+//
+// For GET requests, it merges these params and URL-encodes them:
+//
+//  1. the URL query params
+//  2. params from the --data flag
+//  3. any additional params from the caller
+//
+// For non-GET requests, it merges these params and marshalls them to JSON:
+//
+//  1. params from the --data flag
+//  2. any additional params from the caller
+func BuildDataForV2Request(method string, path string, data []string, additionalParams map[string]interface{}) (string, error) {
+	dataFlagParams, err := parseDataFlag(data)
+	if err != nil {
+		return "", err
+	}
+
+	// GET params are URL encoded
+	if method == http.MethodGet {
+		pathFragment, err := url.Parse(path)
+		if err != nil {
+			return "", err
+		}
+		urlQueryParams := pathFragment.Query()
+		if err := setQueryParams(&urlQueryParams, dataFlagParams); err != nil {
+			return "", err
+		}
+		if err := setQueryParams(&urlQueryParams, additionalParams); err != nil {
+			return "", err
+		}
+		return urlQueryParams.Encode(), nil
+	}
+
+	// non-GET params are marshaled to JSON
+	for k, v := range additionalParams {
+		dataFlagParams[k] = v
+	}
+	marshaled, err := json.Marshal(dataFlagParams)
+	if err != nil {
+		return "", err
+	}
+
+	params := string(marshaled)
+
+	if params == "{}" {
+		params = ""
+	}
+	return params, nil
+}
+
+func parseDataFlag(data []string) (map[string]interface{}, error) {
+	dataFlagParams := make(map[string]interface{})
+	if len(data) == 0 {
+		return dataFlagParams, nil
+	}
+
+	if len(data) > 1 {
+		return nil, fmt.Errorf("v2 API takes request 'data' params in a full json string.")
+	}
+
+	if err := json.Unmarshal([]byte(strings.TrimSpace(data[0])), &dataFlagParams); err != nil {
+		return nil, fmt.Errorf("data is invalid json: %s", data)
+	}
+
+	return dataFlagParams, nil
+}
+
+func setQueryParams(queryParams *url.Values, paramsMap map[string]interface{}) error {
+	for k, v := range paramsMap {
+		switch val := reflect.ValueOf(v); val.Kind() {
+		case reflect.Slice:
+			for _, vv := range v.([]interface{}) {
+				str, err := toString(vv)
+				if err != nil {
+					return err
+				}
+				queryParams.Add(k, str)
+			}
+		default:
+			str, err := toString(v)
+			if err != nil {
+				return err
+			}
+			queryParams.Set(k, str)
+		}
+	}
+	return nil
+}
+
 func (rb *Base) buildMultiPartRequest(params *RequestParameters) (*bytes.Buffer, string, error) {
 	var body bytes.Buffer
 	mp := multipart.NewWriter(&body)
 	defer mp.Close()
+
 	for _, datum := range params.data {
 		splitDatum := strings.SplitN(datum, "=", 2)
 
@@ -449,9 +610,17 @@ func (rb *Base) setIdempotencyHeader(request *http.Request, params *RequestParam
 	}
 }
 
-func (rb *Base) setVersionHeader(request *http.Request, params *RequestParameters) {
-	if params.version != "" {
+func (rb *Base) setVersionHeader(request *http.Request, params *RequestParameters, path string) {
+	switch {
+	case params.version != "":
+		// User explicitly provided a version, use it
 		request.Header.Set("Stripe-Version", params.version)
+	case rb.IsPreviewCommand:
+		// If this is a preview command, use the preview version
+		request.Header.Set("Stripe-Version", StripePreviewVersionHeaderValue)
+	case stripe.IsV2Path(path):
+		// Otherwise, if it's a v2 path, use the normal v2 version
+		request.Header.Set("Stripe-Version", StripeVersionHeaderValue)
 	}
 }
 
@@ -547,3 +716,18 @@ func (rb *Base) experimentalRequestSigning(req *http.Request, experimentalFields
 
 	return nil
 }
+
+func toString(value interface{}) (string, error) {
+	switch val := reflect.ValueOf(value); val.Kind() {
+	case reflect.String:
+		return val.String(), nil
+	case reflect.Float64:
+		return fmt.Sprintf("%v", val.Float()), nil
+	case reflect.Int:
+		return strconv.FormatInt(val.Int(), 10), nil
+	case reflect.Bool:
+		return strconv.FormatBool(val.Bool()), nil
+	default:
+		return "", fmt.Errorf("unsupported query param type: %s", val.Kind().String())
+	}
+}
